@@ -8,7 +8,7 @@
 #' the same set of alternatives are aggregated.
 #' @param free logical; if \code{TRUE} only free choices are included, i.e.
 #' choices of one item from a set of one item are excluded.
-#' @param ... further arguments passed to method (ignored).
+#' @param ... further arguments, currently ignored.
 #' @return A list with the following components
 #' \item{choices}{The selected item(s).}
 #' \item{alternatives}{The set of item(s) that the choice was made from.}
@@ -17,9 +17,21 @@
 #' choice (equal to the ranking weight if \code{aggregate = FALSE}.}
 #' \item{fitted}{The fitted probability of making this choice.}
 #' If \code{object} was a \code{"pltree"} object, the list has an
-#' additional element \code{node}, specifying which node the ranking corresponds
+#' additional element, \code{node}, specifying which node the ranking corresponds
 #' to.
-#' @seealso choices
+#' @seealso \code{\link{choices}}
+#' @examples
+#' R <- matrix(c(1, 2, 0, 0,
+#'               4, 1, 2, 3,
+#'               2, 1, 1, 1,
+#'               1, 2, 3, 0,
+#'               2, 1, 1, 0,
+#'               1, 0, 3, 2), nrow = 6, byrow = TRUE)
+#' colnames(R) <- c("apple", "banana", "orange", "pear")
+#'
+#' mod <- PlackettLuce(R)
+#' fit <- fitted(mod)
+#' fit
 #' @importFrom stats xtabs
 #' @export
 fitted.PlackettLuce <- function(object, aggregate = TRUE, free = TRUE, ...) {
@@ -30,10 +42,7 @@ fitted.PlackettLuce <- function(object, aggregate = TRUE, free = TRUE, ...) {
     alpha <- object$coefficients[id]
     delta <- c(1.0, unname(object$coefficients[-id]))
     # if free = TRUE, ignore forced choice (choice of 1)
-    if (free) {
-        free <- lengths(choices$alternatives) != 1L
-        choices <- lapply(choices, `[`,  free)
-    }
+    if (free) choices <- choices[lengths(choices$alternatives) != 1L,]
     # id unique choices
     unique_choices <- unique(choices$choices)
     g <- match(choices$choices, unique_choices)
@@ -63,7 +72,8 @@ fitted.PlackettLuce <- function(object, aggregate = TRUE, free = TRUE, ...) {
             sequence(na))] <- unlist(unique_alternatives)
     G <- seq_along(unique_alternatives)
     G <- lapply(seq_len(max(na)), function(i) G[na == i])
-    S <- setdiff(unique(na), 1L)
+    S <- unique(na)
+    if (free) S <- setdiff(S, 1L)
     D <- object$maxTied
     N <- ncol(object$rankings)
     theta <- expectation("theta", alpha, delta, a, N, D, S, R, G)$theta
@@ -76,6 +86,22 @@ fitted.PlackettLuce <- function(object, aggregate = TRUE, free = TRUE, ...) {
     }
     choices$fitted <- numerator/denominator
     choices$n <- as.integer(object$weights[unlist(choices$ranking)])
+    if (inherits(object$na.action, "exclude")){
+        n_miss <- length(object$na.action)
+        ranking <- seq_len(max(choices$ranking) + n_miss)[-object$na.action]
+        ranking <- c(ranking[choices$ranking], object$na.action)
+        id <- order(ranking)
+        pad <- rep(NA_integer_, n_miss)
+        old_choices <- choices
+        choices <- data.frame(matrix(NA, nrow = length(ranking), ncol = 0))
+        choices$choices<- c(old_choices$choices, pad)[id]
+        choices$alternatives <- c(old_choices$alternatives, pad)[id]
+        choices$ranking <- ranking[id]
+        choices$fitted <- c(old_choices$fitted, pad)[id]
+        choices$n <- c(old_choices$n, pad)[id]
+        g <- c(g, pad)[id]
+        h <- c(h, pad)[id]
+    } else choices <- as.data.frame(choices)
     if (aggregate){
         if (!is.null(object$adherence)) {
             warning("`aggregate` ignored when `object$adherence` is not `NULL`")
@@ -83,12 +109,33 @@ fitted.PlackettLuce <- function(object, aggregate = TRUE, free = TRUE, ...) {
         }
         g <- paste(g, h, sep = ":")
         g <- match(g, unique(g))
-        choices$ranking <- split(choices$ranking, g)
         keep <- !duplicated(g)
-        agg <- c("choices", "alternatives", "fitted")
-        choices[agg] <- lapply(choices[agg], function(x) x[keep])
-        choices$n <- as.integer(xtabs(choices$n ~ g))
-        class(choices) <- c("aggregated_choices", "list")
+        choices$n[keep] <- unname(rowsum(choices$n, g)[,1])
+        choices$ranking[keep] <- split(choices$ranking, g)
+        choices <- choices[keep,]
+        class(choices) <- c("aggregated_choices", "data.frame")
     }
+    rownames(choices) <- NULL
     choices
 }
+
+#' @rdname fitted.PlackettLuce
+#' @method fitted pltree
+#' @importFrom partykit nodeapply refit.modelparty
+#' @export
+fitted.pltree <- function(object, aggregate = TRUE, free = TRUE, ...)  {
+    node <- predict.pltree(object, type = "node")
+    ids <- nodeids(object, terminal = TRUE)
+    if ("object" %in% object$info$control$terminal) {
+        fit <- nodeapply(object, ids,
+                         function(n) fitted.PlackettLuce(info_node(n)$object))
+    } else {
+        fit <- lapply(refit.modelparty(object, ids, drop = FALSE),
+                      fitted.PlackettLuce)
+    }
+    # combine fitted from each node
+    n <- vapply(fit, function(x) length(x[[1L]]), 1.0)
+    fit <- do.call(Map, c(c, fit))
+    fit$node <- rep.int(ids, n)
+    fit
+}
